==> ed_domain-0.3.15-py3-none-any.whl: ed_domain/common/exceptions.py <==
from enum import StrEnum


class Exceptions(StrEnum):
    BadRequestException = "BadRequestException"
    InternalServerException = "InternalServerException"
    NotFoundException = "NotFoundException"
    SearchNotFoundException = "SearchNotFoundException"
    ValidationException = "ValidationException"
    UnauthorizedException = "UnauthorizedException"
    ForbiddenException = "ForbiddenException"
    ConflictException = "ConflictException"
    TooManyRequestsException = "TooManyRequestsException"
    ServiceUnavailableException = "ServiceUnavailableException"
    GatewayTimeoutException = "GatewayTimeoutException"
    UnprocessableEntityException = "UnprocessableEntityException"
    PreconditionFailedException = "PreconditionFailedException"
    RequestTimeoutException = "RequestTimeoutException"


ERROR_CODES: dict[Exceptions, int] = {
    Exceptions.BadRequestException: 400,
    Exceptions.InternalServerException: 500,
    Exceptions.NotFoundException: 404,
    Exceptions.SearchNotFoundException: 404,
    Exceptions.ValidationException: 400,
    Exceptions.UnauthorizedException: 401,
    Exceptions.ForbiddenException: 403,
    Exceptions.ConflictException: 409,
    Exceptions.TooManyRequestsException: 429,
    Exceptions.ServiceUnavailableException: 503,
    Exceptions.GatewayTimeoutException: 504,
    Exceptions.UnprocessableEntityException: 422,
    Exceptions.PreconditionFailedException: 412,
    Exceptions.RequestTimeoutException: 408,
}

EXCEPTION_NAMES: dict[int, Exceptions] = {
    value: key for key, value in ERROR_CODES.items()
}


class ApplicationException(Exception):
    def __init__(
        self, exception_type: Exceptions, message: str, errors: list[str]
    ) -> None:
        self._message = message
        self._errors = errors
        self._error_code = ERROR_CODES[exception_type]
        super().__init__(self._message)

    @property
    def message(self) -> str:
        return self._message

    @property
    def errors(self) -> list[str]:
        return self._errors

    @property
    def error_code(self) -> int:
        return self._error_code

    def __str__(self) -> str:
        return str(self._message)

==> ed_domain-0.3.22-py3-none-any.whl: ed_domain/common/exceptions.py <==
from enum import StrEnum
from typing import Any


class Exceptions(StrEnum):
    BadRequestException = "BadRequestException"
    InternalServerException = "InternalServerException"
    NotFoundException = "NotFoundException"
    SearchNotFoundException = "SearchNotFoundException"
    ValidationException = "ValidationException"
    UnauthorizedException = "UnauthorizedException"
    ForbiddenException = "ForbiddenException"
    ConflictException = "ConflictException"
    TooManyRequestsException = "TooManyRequestsException"
    ServiceUnavailableException = "ServiceUnavailableException"
    GatewayTimeoutException = "GatewayTimeoutException"
    UnprocessableEntityException = "UnprocessableEntityException"
    PreconditionFailedException = "PreconditionFailedException"
    RequestTimeoutException = "RequestTimeoutException"


ERROR_CODES: dict[Exceptions, int] = {
    Exceptions.BadRequestException: 400,
    Exceptions.InternalServerException: 500,
    Exceptions.NotFoundException: 404,
    Exceptions.SearchNotFoundException: 404,
    Exceptions.ValidationException: 400,
    Exceptions.UnauthorizedException: 401,
    Exceptions.ForbiddenException: 403,
    Exceptions.ConflictException: 409,
    Exceptions.TooManyRequestsException: 429,
    Exceptions.ServiceUnavailableException: 503,
    Exceptions.GatewayTimeoutException: 504,
    Exceptions.UnprocessableEntityException: 422,
    Exceptions.PreconditionFailedException: 412,
    Exceptions.RequestTimeoutException: 408,
}

EXCEPTION_NAMES: dict[int, Exceptions] = {
    value: key for key, value in ERROR_CODES.items()
}


class ApplicationException(Exception):
    def __init__(self, exception_type: Exceptions, message: str, errors: Any) -> None:
        self._message = message
        self._errors = errors
        self._error_code = ERROR_CODES[exception_type]
        super().__init__(self._message)

    @property
    def message(self) -> str:
        return self._message

    @property
    def errors(self) -> Any:
        return self._errors

    @property
    def error_code(self) -> int:
        return self._error_code

    def __str__(self) -> str:
        return str(self._message)
